@@ -41,6 +41,7 @@ ActionGroup = "Actions"
 POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop',
                     'listing', 'undeploy', 'info', 'remove')
 API_VERSION = 1.3
+DEFAULT_REQUEST_TIMEOUT = 200
 
 
 class Dispatcher(object):
@@ -64,6 +65,9 @@ def printer(data):
 
 
 def run_request(req):
+    req.connect_timeout = 5
+    req.request_timeout = options.timeout
+    req.allow_ipv6 = True
     IOLoop.instance().run_sync(lambda: client.fetch(req))
 
 
@@ -127,6 +131,10 @@ define('port', group=CocaineGroup,
        help='Port of buildfarm locator',
        type=int, default=80)
 
+define('timeout', group=CocaineGroup,
+       help='Request timeout',
+       type=int, default=DEFAULT_REQUEST_TIMEOUT)
+
 # ActionGroup
 define('action', group=ActionGroup,
        help='action name (%s)' % '|'.join(POSSIBLE_ACTIONS),
@@ -168,7 +176,6 @@ def upload():
     req = HTTPRequest(gen_url("upload"),
                       method="POST",
                       streaming_callback=default_format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
@@ -185,7 +192,6 @@ def start():
     req = HTTPRequest(gen_url("start"),
                       method="POST",
                       streaming_callback=default_format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
@@ -220,7 +226,6 @@ def deploy():
     req = HTTPRequest(gen_url("deploy"),
                       method="POST",
                       streaming_callback=default_format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
@@ -237,7 +242,6 @@ def undeploy():
     req = HTTPRequest(gen_url("undeploy"),
                       method="POST",
                       streaming_callback=default_format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
@@ -254,7 +258,6 @@ def remove():
     req = HTTPRequest(gen_url("remove"),
                       method="POST",
                       streaming_callback=default_format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
@@ -287,7 +290,6 @@ def listing():
     req = HTTPRequest(gen_url("listing"),
                       method="POST",
                       streaming_callback=format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
@@ -300,7 +302,6 @@ def info():
     req = HTTPRequest(gen_url("info"),
                       method="POST",
                       streaming_callback=default_format_reply,
-                      allow_ipv6=True,
                       body=task)
     run_request(req)
 
